<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 *
 * @package     mod_lanebs
 * @category    Token
 * @copyright   2024 Mazitov Artem
 * @license     http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

declare(strict_types=1);

namespace mod_lanebs\Token;

final class Token implements TokenInterface
{
    /**
     * TODO del session storage
     *
     * @return string|null
     * @throws \dml_exception
     */
    public function get(): ?string
    {
        global $USER;

        if (!empty($_SESSION['mod_lanebs_subscriberToken'])) {
            return (string)$_SESSION['mod_lanebs_subscriberToken'];
        }

        $value = get_config('mod_lanebs', 'token');
        if (!$value) {
            $value = get_config('lanebs', 'token');
        }

        if ($value) {
            $_SESSION['mod_lanebs_subscriberToken'] = (string)$value;
            return $_SESSION['mod_lanebs_subscriberToken'];
        }

        if (!empty($USER->profile['mod_lanebs_token'])) {
            $value = $USER->profile['mod_lanebs_token'];
            $_SESSION['mod_lanebs_subscriberToken'] = (string)$value;
            return $_SESSION['mod_lanebs_subscriberToken'];
        }

        return null;
    }
}